@@ -327,11 +327,117 @@ class VocalSettings(Settings):
             self.context_length: int = None
 
 
+@json_serializable(key_path="./General", value_path="./Value")
+class PatchCNNSettings(Settings):
+    default_setting_file: str = "patch_cnn.yaml"
+
+    def __init__(self, conf_path=None):
+        self.transcription_mode: str = None
+        self.checkpoint_path: dict = None
+        self.feature = self.PatchCNNFeature()
+        self.model = self.PatchCNNModel()
+        self.dataset = self.PatchCNNDataset()
+        self.training = self.PatchCNNTraining()
+        self.inference = self.PatchCNNInference()
+
+        super().__init__(conf_path=conf_path)
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class PatchCNNFeature:
+        def __init__(self):
+            self.patch_size: int = None
+            self.peak_threshold: float = None
+            self.sampling_rate: int = None
+            self.hop_size: float = None
+            self.window_size: int = None
+            self.frequency_resolution: float = None
+            self.frequency_center: float = None
+            self.time_center: float = None
+            self.gamma: list = None
+            self.bins_per_octave: int = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class PatchCNNModel:
+        def __init__(self):
+            self.save_prefix: str = None
+            self.save_path: str = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class PatchCNNDataset:
+        def __init__(self):
+            self.save_path: str = None
+            self.feature_save_path: str = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class PatchCNNTraining:
+        def __init__(self):
+            self.epoch: int = None
+            self.steps: int = None
+            self.val_steps: int = None
+            self.batch_size: int = None
+            self.val_batch_size: int = None
+            self.early_stop: int = None
+            self.init_learning_rate: float = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class PatchCNNInference:
+        def __init__(self):
+            self.threshold: float = None
+            self.max_method: str = None
+
+
+@json_serializable(key_path="./General", value_path="./Value")
 class BeatSettings(Settings):
     default_setting_file: str = "beat.yaml"
 
     def __init__(self, conf_path=None):
         self.transcription_mode: str = None
         self.checkpoint_path: dict = None
+        self.feature = self.BeatFeature()
+        self.dataset = self.BeatDataset()
+        self.model = self.BeatModel()
+        self.training = self.BeatTraining()
+        self.inference = self.BeatInference()
 
         super().__init__(conf_path=conf_path)
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class BeatFeature:
+        def __init__(self):
+            self.time_unit: float = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class BeatDataset:
+        def __init__(self):
+            self.save_path: str = None
+            self.feature_save_path: str = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class BeatModel:
+        def __init__(self):
+            self.save_prefix: str = None
+            self.save_path: str = None
+            self.model_type: str = None
+            self.timesteps: int = None
+            self.lstm_hidden_dim: int = None
+            self.num_lstm_layers: int = None
+            self.attn_hidden_dim: int = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class BeatTraining:
+        def __init__(self):
+            self.epoch: int = None
+            self.steps: int = None
+            self.val_steps: int = None
+            self.batch_size: int = None
+            self.val_batch_size: int = None
+            self.early_stop: int = None
+            self.init_learning_rate: float = None
+            self.down_beat_weight: float = None
+
+    @json_serializable(key_path="./Settings", value_path="./Value")
+    class BeatInference:
+        def __init__(self):
+            self.beat_threshold: float = None
+            self.down_beat_threshold: float = None
+            self.min_distance: float = None
